RuntimeBuilder

Struct RuntimeBuilder 

pub struct RuntimeBuilder { /* private fields */ }
Builder for configuring and creating a Runtime

Implementations

Source

impl RuntimeBuilder

pub fn from_path(self, path: impl Into<PathBuf>) -> Self

Add a definition source path (.toml, .wasm, oci://, etc.)

pub fn from_paths(self, paths: &[PathBuf]) -> Self

Add multiple definition source paths

pub fn with_definition_loader(self, loader: Box<dyn DefinitionLoader>) -> Self

Register a custom definition loader

pub fn with_config_handler(self, handler: Box<dyn ConfigHandler>) -> Self

Register a standalone config handler

pub fn no_default_loaders(self) -> Self

Opt out of the default TomlLoader + WasmLoader

pub fn with_service<T: Service + Default + 'static>(self) -> Self

Register a lifecycle-managed service.

The service’s config handler (if any) participates in config parsing. Its capabilities are registered after config parsing. Its start() and shutdown() are called during the runtime lifecycle.

pub fn with_capability<T>(self, name: &'static str) -> Self
where T: HostCapability + DeserializeOwned + Default + 'static,

Register a host capability type for the given name.

The name corresponds to the type value in [capability.*] TOML blocks.

If the config is empty and deserialization fails, falls back to Default::default().

pub async fn build(self) -> Result<Runtime>

Build the Runtime: load config, build graph, build registries, create component host