DefinitionLoader

Trait DefinitionLoader 

pub trait DefinitionLoader {
    // Required method
    fn load(&self) -> Result<Vec<GenericDefinition>>;

    // Provided method
    fn claim(&mut self, _path: &Path) -> bool { ... }
}
Reads configuration from a source and produces generic definitions.

Required Methods

fn load(&self) -> Result<Vec<GenericDefinition>>

Load definitions from all claimed paths and/or internal sources.

Provided Methods

fn claim(&mut self, _path: &Path) -> bool

Claim a path and store it if this loader should handle it. Default returns false for self-contained loaders.

Implementors